#!/bin/bash

if [ "$#" -ne 2 ]; then
    echo ""
    echo "Usage: $0 <backup_store_IP> <backup_mount_name>"
    echo ""
    echo "      <backup_store_IP> : IP address of the Phoenix Backup Store"
    echo "      <backup_mount_name> : Name of the backup mount configured in Phoenix, e.g. mount1"

    exit 1
fi

BACKUP_STORE_IP=$1
BACKUP_MOUNT=$2

res=$(curl -X POST http://$BACKUP_STORE_IP:9090/druva-phoenix/v1/mounts/$BACKUP_MOUNT/backup 2> /dev/null)
if [ $? -ne 0 ];
then
    echo "Request to start phoenix backup failed... exiting"
    echo "Response from Phoenix Backup Store: "$res
    exit 1
fi

# Sample output format
# {"error_code":4295622665,"error_msg":"Backup mount does not exist on Export Service.","result":{"mount_name":"mount4","mount_path":""}}
ERROR_CODE=$(echo $res|awk -F "error_code" '{print $2}' | cut -d ':' -f2|cut -d ',' -f1)
if [ $ERROR_CODE -ne 0 ];
then
    echo "Response from Phoenix Backup Store: "$res
    echo "Error getting mount details... exiting"
    exit 1
fi

REMOTE_MOUNTPOINT=$BACKUP_STORE_IP:$(echo $res|awk -F "mount_path" '{print $2}'|cut -d '"' -f3)
echo ""
echo "Remote mountpath is $REMOTE_MOUNTPOINT"
MOUNT_OPTS=$(echo $res|awk -F "mount_params" '{print $2}'|cut -d '{' -f2|cut -d '}' -f1)
echo "Mount options : rw,user,$MOUNT_OPTS"
